==> nextcloud-app-calendar-1:5.5.2-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/calendar/l10n/eo.js <==
OC.L10N.register(
    "calendar",
    {
    "%s has published the calendar »%s«" : "%s publikigis la kalendaron „%s“",
    "Hello," : "Saluton,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Ni volis sciigi vin, ke %s publikigis la kalendaron „%s“.",
    "Open »%s«" : "Malfermi „%s“",
    "Cheers!" : "Ĝis!",
    "Upcoming events" : "Venontaj eventoj",
    "No more events today" : "Ne plu eventoj hodiaŭ",
    "No upcoming events" : "Neniuj venontaj eventoj",
    "More events" : "Pliaj eventoj",
    "Calendar" : "Kalendaro",
    "New booking {booking}" : "Nova rezervo {booking}",
    "Confirm" : "Konfirmi",
    "Description:" : "Priskribo:",
    "Date:" : "Dato:",
    "Where:" : "Kie:",
    "Comment:" : "Komento:",
    "A Calendar app for Nextcloud" : "Aplikaĵo pri kalendaro por Nextcloud",
    "Today" : "Hodiaŭ",
    "Day" : "Tago",
    "Week" : "Semajno",
    "Month" : "Monato",
    "Preview" : "Antaŭvidi",
    "Copy link" : "Kopii ligilon",
    "Edit" : "Modifi",
    "Delete" : "Forigi",
    "Create new" : "Krei nove",
    "New calendar" : "Nova kalendaro",
    "Calendar link copied to clipboard." : "Kalendara ligilo kopiita al tondujo",
    "Calendar link could not be copied to clipboard." : "Kalendara ligilo ne eblis esti kopiita al tondujo",
    "Export" : "Eksporti",
    "Empty trash bin" : "Malpleni rubujon",
    "Name" : "Nomo",
    "Deleted" : "Forigita",
    "Restore" : "Restaŭri",
    "Delete permanently" : "Forigi por ĉiam",
    "Deck" : "Kartaro",
    "Hidden" : "Nevidebla",
    "Internal link" : "Interna ligilo",
    "Share link" : "Kunhavigi ligilon",
    "Delete share link" : "Forigi kunhavo-ligilon",
    "can edit" : "povas redakti",
    "Share with users or groups" : "Kunhavigi kun uzantoj aŭ grupoj",
    "No users or groups" : "Neniu uzanto aŭ grupo",
    "Save" : "Konservi",
    "View" : "Vidi",
    "Filename" : "Dosiernomo",
    "Cancel" : "Nuligi",
    "Automatic" : "Aŭtomata",
    "Previous period" : "Antaŭa periodo",
    "List view" : "Lista vido",
    "Actions" : "Agoj",
    "Editor" : "Redaktilo",
    "Close editor" : "Fermi redaktilon",
    "or" : "aŭ",
    "Enable birthday calendar" : "Ebligi naskiĝtaga kalendaro",
    "Show tasks in calendar" : "Montri taskojn en la kalendaro",
    "Enable simplified editor" : "Ebligi simpligitan redaktilon",
    "Show weekends" : "Montri semajnfinojn",
    "Show week numbers" : "Montri numerojn de semajno",
    "Show keyboard shortcuts" : "Montri klavarajn ŝparvojojn",
    "Update" : "Ĝisdatigi",
    "Location" : "Loko",
    "Description" : "Priskribo",
    "to" : "al",
    "Add" : "Aldoni",
    "Monday" : "Lundo",
    "Tuesday" : "Mardo",
    "Wednesday" : "Merkredo",
    "Thursday" : "Ĵaŭdo",
    "Friday" : "Vendredo",
    "Saturday" : "Sabato",
    "Sunday" : "Dimanĉo",
    "Before the event" : "Antaŭe la evento",
    "After the event" : "Post la evento",
    "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "Ni sendis al vi retmesaĝon kun detaloj. Bonvolu konfirmi vian rendevuon per la ligilo en la retpoŝto. Vi povas fermi ĉi tiun paĝon nun.",
    "Your email address" : "Via retpoŝta adreso",
    "Notification" : "Atentigo",
    "Email" : "Retpoŝto",
    "seconds" : "sekundoj",
    "minutes" : "minutoj",
    "hours" : "horojn",
    "days" : "tagojn",
    "weeks" : "semajnoj",
    "Choose a file to add as attachment" : "Elektu dosieron aldonotan kiel kunsendaĵon",
    "Delete file" : "Forigi dosieron",
    "Available" : "Disponeble",
    "Not available" : "Ne disponeble",
    "Out of office" : "Ekstere oficejo",
    "Done" : "Farita",
    "Busy" : "Okupita",
    "Unknown" : "Nekonata",
    "Accept" : "Akcepti",
    "Decline" : "Malakcepti",
    "Tentative" : "Nekonfirmita",
    "Attendees" : "Ĉeestontoj",
    "Remove group" : "Forigi grupon",
    "Required participant" : "Bezonata partoprenanto",
    "Optional participant" : "Laŭvola partoprenanto",
    "From" : "De",
    "To" : "Al",
    "Repeat" : "Ripeti",
    "never" : "neniam",
    "after" : "post",
    "first" : "Una",
    "By day of the month" : "Per tago de la monato",
    "On the" : "Je la",
    "_day_::_days_" : ["tago","tagoj"],
    "_week_::_weeks_" : ["semajno","semajnoj"],
    "_month_::_months_" : ["Monato","Monatoj"],
    "_year_::_years_" : ["Jaro","Jaroj"],
    "weekday" : "Semajntago",
    "weekend day" : "Semajnfintago",
    "Resources" : "Rimedoj",
    "on {formattedDate}" : "je la {formattedDate}",
    "Global" : "Monda",
    "Subscribe" : "Aboni",
    "Time:" : "Tempo:",
    "Personal" : "Persona",
    "Edit event" : "Redakti okazaĵon",
    "All day" : "Tuttage",
    "Untitled event" : "Sentitola okazaĵo",
    "Close" : "Fermi",
    "Anniversary" : "Datreveno",
    "Week {number} of {year}" : "Semajno {number} en {year}",
    "Daily" : "Ĉiutage",
    "Weekly" : "Ĉiusemajne",
    "second" : "sekundo",
    "third" : "Tria",
    "fourth" : "Kvara",
    "fifth" : "Kvina",
    "last" : "Lasta",
    "Other" : "Alia",
    "When shared show full event" : "Kiam kunhavigita, montri plenajn detalojn",
    "When shared show only busy" : "Kiam kunhavigita, montri nur kiel okupita",
    "When shared hide this event" : "Kiam kunhavigita, kaŝi tiun okazaĵon",
    "Status" : "Stato",
    "Confirmed" : "Konfirmita",
    "Canceled" : "Nuligita",
    "Categories" : "Kategorioj",
    "Add this as a new category" : "Aldoni tion kiel novan kategorion",
    "User not found" : "Netrovita uzanto"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-calendar-1:5.5.3-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/calendar/l10n/eo.js <==
OC.L10N.register(
    "calendar",
    {
    "%s has published the calendar »%s«" : "%s publikigis la kalendaron „%s“",
    "Hello," : "Saluton,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Ni volis sciigi vin, ke %s publikigis la kalendaron „%s“.",
    "Open »%s«" : "Malfermi „%s“",
    "Cheers!" : "Ĝis!",
    "Upcoming events" : "Venontaj eventoj",
    "No more events today" : "Ne plu eventoj hodiaŭ",
    "No upcoming events" : "Neniuj venontaj eventoj",
    "More events" : "Pliaj eventoj",
    "Calendar" : "Kalendaro",
    "New booking {booking}" : "Nova rezervo {booking}",
    "Confirm" : "Konfirmi",
    "Description:" : "Priskribo:",
    "Date:" : "Dato:",
    "Where:" : "Kie:",
    "Comment:" : "Komento:",
    "Location:" : "Loko:",
    "A Calendar app for Nextcloud" : "Aplikaĵo pri kalendaro por Nextcloud",
    "Today" : "Hodiaŭ",
    "Day" : "Tago",
    "Week" : "Semajno",
    "Month" : "Monato",
    "Preview" : "Antaŭvidi",
    "Copy link" : "Kopii ligilon",
    "Edit" : "Modifi",
    "Delete" : "Forigi",
    "Create new" : "Krei nove",
    "New calendar" : "Nova kalendaro",
    "Calendar link copied to clipboard." : "Kalendara ligilo kopiita al tondujo",
    "Calendar link could not be copied to clipboard." : "Kalendara ligilo ne eblis esti kopiita al tondujo",
    "Export" : "Eksporti",
    "Empty trash bin" : "Malpleni rubujon",
    "Name" : "Nomo",
    "Deleted" : "Forigita",
    "Restore" : "Restaŭri",
    "Delete permanently" : "Forigi por ĉiam",
    "Deck" : "Kartaro",
    "Hidden" : "Nevidebla",
    "Internal link" : "Interna ligilo",
    "Share link" : "Kunhavigi ligilon",
    "Delete share link" : "Forigi kunhavo-ligilon",
    "can edit" : "povas redakti",
    "Share with users or groups" : "Kunhavigi kun uzantoj aŭ grupoj",
    "No users or groups" : "Neniu uzanto aŭ grupo",
    "Save" : "Konservi",
    "View" : "Vidi",
    "Filename" : "Dosiernomo",
    "Cancel" : "Nuligi",
    "Automatic" : "Aŭtomata",
    "Timezone" : "Horzono",
    "Previous period" : "Antaŭa periodo",
    "List view" : "Lista vido",
    "Actions" : "Agoj",
    "Editor" : "Redaktilo",
    "Close editor" : "Fermi redaktilon",
    "or" : "aŭ",
    "General" : "Ĝenerala",
    "Enable birthday calendar" : "Ebligi naskiĝtaga kalendaro",
    "Show tasks in calendar" : "Montri taskojn en la kalendaro",
    "Show weekends" : "Montri semajnfinojn",
    "Show week numbers" : "Montri numerojn de semajno",
    "Keyboard shortcuts" : "Fulmoklavoj",
    "Update" : "Ĝisdatigi",
    "Location" : "Loko",
    "Description" : "Priskribo",
    "to" : "al",
    "Add" : "Aldoni",
    "Monday" : "Lundo",
    "Tuesday" : "Mardo",
    "Wednesday" : "Merkredo",
    "Thursday" : "Ĵaŭdo",
    "Friday" : "Vendredo",
    "Saturday" : "Sabato",
    "Sunday" : "Dimanĉo",
    "Before the event" : "Antaŭe la evento",
    "After the event" : "Post la evento",
    "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "Ni sendis al vi retmesaĝon kun detaloj. Bonvolu konfirmi vian rendevuon per la ligilo en la retpoŝto. Vi povas fermi ĉi tiun paĝon nun.",
    "Your email address" : "Via retpoŝta adreso",
    "Notification" : "Atentigo",
    "Email" : "Retpoŝto",
    "seconds" : "sekundoj",
    "minutes" : "minutoj",
    "hours" : "horojn",
    "days" : "tagojn",
    "weeks" : "semajnoj",
    "Choose a file to add as attachment" : "Elektu dosieron aldonotan kiel kunsendaĵon",
    "Delete file" : "Forigi dosieron",
    "Available" : "Disponeble",
    "Not available" : "Ne disponeble",
    "Out of office" : "Ekstere oficejo",
    "Done" : "Farita",
    "Busy" : "Okupita",
    "Unknown" : "Nekonata",
    "Accept" : "Akcepti",
    "Decline" : "Malakcepti",
    "Tentative" : "Nekonfirmita",
    "Attendees" : "Ĉeestontoj",
    "Remove group" : "Forigi grupon",
    "Required participant" : "Bezonata partoprenanto",
    "Optional participant" : "Laŭvola partoprenanto",
    "From" : "De",
    "To" : "Al",
    "Repeat" : "Ripeti",
    "never" : "neniam",
    "after" : "post",
    "first" : "Una",
    "By day of the month" : "Per tago de la monato",
    "On the" : "Je la",
    "_day_::_days_" : ["tago","tagoj"],
    "_week_::_weeks_" : ["semajno","semajnoj"],
    "_month_::_months_" : ["Monato","Monatoj"],
    "_year_::_years_" : ["Jaro","Jaroj"],
    "weekday" : "Semajntago",
    "weekend day" : "Semajnfintago",
    "Resources" : "Rimedoj",
    "Yes" : "Jes",
    "No" : "Ne",
    "on {formattedDate}" : "je la {formattedDate}",
    "Global" : "Monda",
    "Subscribe" : "Aboni",
    "Time:" : "Tempo:",
    "Personal" : "Persona",
    "Edit event" : "Redakti okazaĵon",
    "All day" : "Tuttage",
    "Untitled event" : "Sentitola okazaĵo",
    "Close" : "Fermi",
    "Submit" : "Sendi",
    "Anniversary" : "Datreveno",
    "Week {number} of {year}" : "Semajno {number} en {year}",
    "Daily" : "Ĉiutage",
    "Weekly" : "Ĉiusemajne",
    "second" : "sekundo",
    "third" : "Tria",
    "fourth" : "Kvara",
    "fifth" : "Kvina",
    "last" : "Lasta",
    "Other" : "Alia",
    "When shared show full event" : "Kiam kunhavigita, montri plenajn detalojn",
    "When shared show only busy" : "Kiam kunhavigita, montri nur kiel okupita",
    "When shared hide this event" : "Kiam kunhavigita, kaŝi tiun okazaĵon",
    "Status" : "Stato",
    "Confirmed" : "Konfirmita",
    "Canceled" : "Nuligita",
    "Categories" : "Kategorioj",
    "Add this as a new category" : "Aldoni tion kiel novan kategorion",
    "User not found" : "Netrovita uzanto",
    "Enable simplified editor" : "Ebligi simpligitan redaktilon",
    "Show keyboard shortcuts" : "Montri klavarajn ŝparvojojn"
},
"nplurals=2; plural=(n != 1);");
